abacusai.api_class.dataset_application_connector — AbacusAI documentation

# `abacusai.api_class.dataset_application_connector`

## Module Contents

### Classes

`DatasetConfig` | Helper class that provides a standard way to create an ABC using
`ConfluenceDatasetConfig` | Dataset config for Confluence Application Connector
`GoogleAnalyticsDatasetConfig` | Dataset config for Google Analytics Application Connector
`GoogleDriveDatasetConfig` | Dataset config for Google Drive Application Connector
`JiraDatasetConfig` | Dataset config for Jira Application Connector
`OneDriveDatasetConfig` | Dataset config for OneDrive Application Connector
`SharepointDatasetConfig` | Dataset config for Sharepoint Application Connector
`ZendeskDatasetConfig` | Dataset config for Zendesk Application Connector
`AbacusUsageMetricsDatasetConfig` | Dataset config for Abacus Usage Metrics Application Connector
`_DatasetConfigFactory` | Helper class that provides a standard way to create an ABC using

class abacusai.api_class.dataset_application_connector.DatasetConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  application_connector_type: abacusai.api_class.enums.ApplicationConnectorType
  classmethod _get_builder()

class abacusai.api_class.dataset_application_connector.ConfluenceDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Confluence Application Connector :param pull_attachments: Whether to pull attachments for each page :type pull_attachments: bool, optional :param space_key: The space key to fetch pages from :type space_key: str, optional

  pull_attachments: bool
  space_key: str
  __post_init__()

class abacusai.api_class.dataset_application_connector.GoogleAnalyticsDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Google Analytics Application Connector

  Parameters:

    - location (str) – The view id of the report in the connector to fetch

    - start_timestamp (int, optional) – Unix timestamp of the start of the period that will be queried

    - end_timestamp (int, optional) – Unix timestamp of the end of the period that will be queried

  location: str
  start_timestamp: int
  end_timestamp: int
  __post_init__()

class abacusai.api_class.dataset_application_connector.GoogleDriveDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Google Drive Application Connector

  Parameters:

    - location (str) – The regex location of the files to fetch

    - is_documentset (bool) – Whether the dataset is a document set

    - csv_delimiter (str, optional) – If the file format is CSV, use a specific csv delimiter

    - extract_bounding_boxes (bool, optional) – Signifies whether to extract bounding boxes out of the documents. Only valid if is_documentset if True

    - merge_file_schemas (bool, optional) – Signifies if the merge file schema policy is enabled. Not applicable if is_documentset is True

  location: str
  is_documentset: bool
  csv_delimiter: str
  extract_bounding_boxes: bool
  merge_file_schemas: bool
  __post_init__()

class abacusai.api_class.dataset_application_connector.JiraDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Jira Application Connector

  Parameters:

    - jql (str) – The JQL query for fetching issues

    - custom_fields (list, optional) – A list of custom fields to include in the dataset

    - include_comments (bool, optional) – Fetch comments for each issue

    - include_watchers (bool, optional) – Fetch watchers for each issue

  jql: str
  custom_fields: list
  include_comments: bool
  include_watchers: bool
  __post_init__()

class abacusai.api_class.dataset_application_connector.OneDriveDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for OneDrive Application Connector

  Parameters:

    - location (str) – The regex location of the files to fetch

    - is_documentset (bool) – Whether the dataset is a document set

    - csv_delimiter (str, optional) – If the file format is CSV, use a specific csv delimiter

    - extract_bounding_boxes (bool, optional) – Signifies whether to extract bounding boxes out of the documents. Only valid if is_documentset if True

    - merge_file_schemas (bool, optional) – Signifies if the merge file schema policy is enabled. Not applicable if is_documentset is True

  location: str
  is_documentset: bool
  csv_delimiter: str
  extract_bounding_boxes: bool
  merge_file_schemas: bool
  __post_init__()

class abacusai.api_class.dataset_application_connector.SharepointDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Sharepoint Application Connector

  Parameters:

    - location (str) – The regex location of the files to fetch

    - is_documentset (bool) – Whether the dataset is a document set

    - csv_delimiter (str, optional) – If the file format is CSV, use a specific csv delimiter

    - extract_bounding_boxes (bool, optional) – Signifies whether to extract bounding boxes out of the documents. Only valid if is_documentset if True

    - merge_file_schemas (bool, optional) – Signifies if the merge file schema policy is enabled. Not applicable if is_documentset is True

  location: str
  is_documentset: bool
  csv_delimiter: str
  extract_bounding_boxes: bool
  merge_file_schemas: bool
  __post_init__()

class abacusai.api_class.dataset_application_connector.ZendeskDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Zendesk Application Connector

  __post_init__()

class abacusai.api_class.dataset_application_connector.AbacusUsageMetricsDatasetConfig

  Bases: `DatasetConfig`

  Dataset config for Abacus Usage Metrics Application Connector

  Parameters:

    include_entire_conversation_history (bool) – Whether to show the entire history for this deployment conversation

  include_entire_conversation_history: bool
  __post_init__()

class abacusai.api_class.dataset_application_connector._DatasetConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'application_connector_type'
  config_class_map